<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="mk">
<context>
    <name>ClipGrab</name>
    <message>
        <location filename="clipgrab.cpp" line="36"/>
        <source>Automatic language recognition</source>
        <translation>Автоматско препознавање на јазик</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="512"/>
        <source>Downloading update … %1/%2 MBytes</source>
        <translation>Преземање на ажурирање ... %1/%2 МБајти</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="521"/>
        <source>There was an error while downloading the update.: %1</source>
        <translation>Настана грешка при преземањето на ажурирањето.: %1</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="535"/>
        <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
        <translation>Отпечатокот на преземаното ажурирање неможе да биде потврдено: %1 би требало да биде %2</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="547"/>
        <source>Could not open update file.</source>
        <translation>Фајлот за ажурирање неможе да биде отворен.</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="585"/>
        <source>Unable to write to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="607"/>
        <source>SSL error: %1 
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="614"/>
        <source>Error downloading youtube-dl: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>GiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>TiB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadListModel</name>
    <message>
        <location filename="download_list_model.cpp" line="99"/>
        <source>Starting ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="106"/>
        <source>Converting ...</source>
        <translation type="unfinished">Се конвертира ...</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="108"/>
        <source>Finished</source>
        <translation type="unfinished">Завршено</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="110"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="112"/>
        <source>Canceled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="114"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="116"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Portal</source>
        <translation type="unfinished">Портал</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Title</source>
        <translation type="unfinished">Наслов</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Format</source>
        <translation type="unfinished">Формат</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Progress</source>
        <translation type="unfinished">Напредок</translation>
    </message>
</context>
<context>
    <name>HelperDownloader</name>
    <message>
        <location filename="helper_downloader.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished">Прозорец</translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="20"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="27"/>
        <source>Exit ClipGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="85"/>
        <source>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to download youtube-dl.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to automatically download youtube-dl.&lt;/p&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="99"/>
        <source>Downloading youtube-dl</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="273"/>
        <source>Select Target</source>
        <translation>Одберете целна локација</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="74"/>
        <source>Please wait while ClipGrab is loading information about the video ...</source>
        <translation>Ве молиме почекајте додека ClipGrab вчитува информации за видеото ...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Ве молиме внесете го линкот на видеото кое сакате да го преземете во полето подолу.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
        <translation>Видео кое би можело да се преземе неможе да биде пронајдено.&lt;br /&gt;Можеби имате внесено погрешен линк или пак имате проблем со вашата интернет врска.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="376"/>
        <source>ClipGrab - Select target path</source>
        <translation>ClipGrab - Одберете ја патеката до целната локација</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab: Video discovered in your clipboard</source>
        <translation>ClipGrab: Откриено е видео во вашиот клипборд</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
        <translation>ClipGrab ја откри адресата на компатибилно видео во вашиот клипборд. Кликнете на оваа порака за да го преземете сега.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>ClipGrab - Exit confirmation</source>
        <translation>ClipGrab - Потврда за излез</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
        <translation>Сеуште има барем едно преземање кое е во тек.&lt;br /&gt;Ако излезете од програмата сега, сите преземања ќе бидат откажани и нема да можат да се вратат или обноват подоцна.&lt;br /&gt;Дали навистина сакате да го запрете ClipGrab сега?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Download finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Downloading and converting “%title” is now finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>All downloads finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>ClipGrab has finished downloading and converting all selected videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="683"/>
        <source>No results found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="740"/>
        <source>&amp;Open downloaded file</source>
        <translation>&amp;Отворете го преземаното видео</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="741"/>
        <source>Open &amp;target folder</source>
        <translation>Отворете го &amp;целниот фолдер (локација)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="743"/>
        <source>&amp;Pause download</source>
        <translation>&amp;Паузирајте го преземањето</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="744"/>
        <source>&amp;Restart download</source>
        <translation>&amp;Рестартирајте го преземањето</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="745"/>
        <source>&amp;Cancel download</source>
        <translation>&amp;Откажете го преземањето</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="747"/>
        <source>Copy &amp;video link</source>
        <translation>Копирајте го линкот од &amp;видеото</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="748"/>
        <source>Open video link in &amp;browser</source>
        <translation>Отворете го линкот од видеото во &amp;прелистувач</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="751"/>
        <source>Resume download</source>
        <translation>Продолжете го преземањето</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="764"/>
        <source>Show in &amp;Finder</source>
        <translation>Покажи го во &amp;Пронаоѓачот</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation>ClipGrab - Преземете и конвертирајте онлајн видеа</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="153"/>
        <source>Search</source>
        <translation>Пребарување</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Enter keywords in the box below in order to search videos on YouTube</source>
        <translation>Внесете клучни зборови во полето подолу за да пребарувате видеа на YouTube</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Downloads</source>
        <translation>Преземања</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="199"/>
        <source>Grab this clip!</source>
        <translation>Зграби го овој клип!</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="234"/>
        <source>Quality:</source>
        <translation>Квалитет:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Ве молиме внесете го линкот од видеото кое сакате да го преземете во полето подолу.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="343"/>
        <source>Current Downloads:</source>
        <translation>Тековни преземања:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="363"/>
        <source>Cancel selected download</source>
        <translation>Откажете го 
селектираното преземање</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="353"/>
        <source>Open the target folder of the selected download</source>
        <translation>Отворете го целниот фолдер за 
селектираното преземање</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="373"/>
        <source>Pause selected download</source>
        <translation>Паузирајте го 
селектираното преземање</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="385"/>
        <source>Settings</source>
        <translation>Поставки</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>General</source>
        <translation>Општо</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
        <translation>Овде можете да прилагодите некои општи поставки во врска со однесувањето на ClipGrab.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="433"/>
        <source>Target Path</source>
        <translation>Целна локација</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="439"/>
        <source>Always save at the last used path.</source>
        <translation>Секогаш зачувувај на последната користена локација.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="453"/>
        <source>Here you can configure where the downloaded videos are to be saved.</source>
        <translation>Овде можете да одберете каде вашите преземени видеа ќе бидат зачувани.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <source>Browse ...</source>
        <translation>Прегледајте ...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Never ask for file name</source>
        <translation>Никогаш не прашувај за име на фајл</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="488"/>
        <source>Metadata</source>
        <translation>Metadata</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="494"/>
        <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
        <translation>Овде можете да одберете дали ClipGrab да додава metadata (ID3 тагови) во вашите mp3 фајлови.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="501"/>
        <source>Use metadata</source>
        <translation>Користи metadata</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="522"/>
        <source>Clipboard</source>
        <translation>Клипборд</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="528"/>
        <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
        <translation>Овде можете да одберете како ClipGrab да се однесува кога во вашиот клипборд ќе биде откриено 
видео кое може да се преземе.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="535"/>
        <source>Always download</source>
        <translation>Секогаш преземај</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Never download</source>
        <translation>Никогаш не преземај</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="549"/>
        <source>Always ask</source>
        <translation>Секогаш прашувај</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="570"/>
        <source>Notifications</source>
        <translation>Известувања</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <source>After each download</source>
        <translation>По секое преземање</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="583"/>
        <source>After all downloads have been completed</source>
        <translation>Откако сите преземања се завршени</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="603"/>
        <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
        <translation>Овде можете да одберете кога ClipGrab да прикажува известувања.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="610"/>
        <source>Never</source>
        <translation>Никогаш</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="618"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <source>Use a proxy server</source>
        <translation>Користи proxy сервер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Proxy settings</source>
        <translation>Поставки за proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="643"/>
        <source>Hostname/IP:</source>
        <translation>Име на host/IP:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="650"/>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="677"/>
        <source>Proxy type:</source>
        <translation>Тип на proxy:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="685"/>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="690"/>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="717"/>
        <source>Proxy authentication</source>
        <translation>Автентикација за proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="723"/>
        <source>Username:</source>
        <translation>Корисничко име:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="740"/>
        <source>Password:</source>
        <translation>Лозинка:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="753"/>
        <source>Proxy requires authentication</source>
        <translation>Proxy бара автентикација</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="761"/>
        <source>Other</source>
        <translation>Останато</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>Remove finished downloads from list</source>
        <translation>Отстранувај ги од листата завршените преземања</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1182"/>
        <source>&lt;h2&gt;Thanks&lt;/h2&gt;
ClipGrab relies on the work of the Qt project, the ffmpeg team, and the youtube-dl team.&lt;br&gt;
Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt;, and &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; for further information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="767"/>
        <source>Minimize ClipGrab to the system tray</source>
        <translation>Минимизирај го ClipGrab во системската tray лента</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="774"/>
        <source>Use WebM if possible</source>
        <translation>Користи го WebM доколку тоа е возможно</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="781"/>
        <source>Ignore SSL errors</source>
        <translation>Игнорирај ги SSL грешките</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="808"/>
        <source>Remember logins</source>
        <translation>Памети ги логирањата</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="815"/>
        <source>Remember video quality</source>
        <translation>Памети го квалитетот на видеото</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="827"/>
        <source>Language</source>
        <translation>Јазик</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="851"/>
        <source>Here you can change the language of ClipGrab.</source>
        <translation>Овде можете да го промените јазикот на кој е прикажан ClipGrab.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="858"/>
        <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
        <translation>Ве молиме одберете јазик од листата подолу. Морате да го рестартирате ClipGrab за вашиот избор 
да се аплицира.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="895"/>
        <source>Conversion</source>
        <translation>Конверзија</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="918"/>
        <source>Experts can create custom presets for the video conversion here.</source>
        <translation>Експертите овде ќе можат да креираат лични пресети за видео конверзијата.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="925"/>
        <source>Format preset</source>
        <translation>Формат на пресетот</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Add new preset</source>
        <translation>Додадете нов пресет</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="942"/>
        <source>Remove selected preset</source>
        <translation>Отстранете го 
селектираниот пресет</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="965"/>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="977"/>
        <location filename="mainwindow.ui" line="1029"/>
        <source>Codec</source>
        <translation>Кодек</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1003"/>
        <location filename="mainwindow.ui" line="1091"/>
        <source>Bitrate (kb/s)</source>
        <translation>Bitrate (kb/s)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1010"/>
        <source>Disable Audio</source>
        <translation>Оневозможи аудио</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1042"/>
        <source>Frames/second</source>
        <translation>Фрејмови/секунда</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1101"/>
        <source>Disable video</source>
        <translation>Оневозможи видео</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1116"/>
        <source>About</source>
        <translation>За</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1122"/>
        <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
&lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Поддржете го ClipGrab!&lt;/h2&gt;
&lt;p&gt;Само со вашата поддршка, ClipGrab може да остане слободен софтвер!&lt;br&gt;Затоа ако ви се допаѓа ClipGrab и сакате да помогнете и да го осигурате понатамошното развивање, ве молиме размислете да направите донација.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1165"/>
        <source>&lt;h2&gt;Translation&lt;/h2&gt;
ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
        <translation>&lt;h2&gt;Превод&lt;/h2&gt;
ClipGrab веќе е достапен во повеќе јазици. Ако ClipGrab сеуште не бил преведен на вашиот јазик и сакате да придонесете превод, ве молиме проверете на &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; за понатамошни информации.</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="metadata-dialog.ui" line="14"/>
        <source>ClipGrab - enter metadata</source>
        <translation>ClipGrab - внесете  metadata</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="25"/>
        <source>Please enter the metadata for your download. If you don&apos;t want to add metadata, just leave the fields empty.</source>
        <translation>Ве молиме внесете metadata за вашиот преземан фајл. Ако не сакате да додадете metadata, 
само оставете ги полињата празни.</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="45"/>
        <source>Title:</source>
        <translation>Наслов:</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="52"/>
        <source>Artist:</source>
        <translation>Артист:</translation>
    </message>
</context>
<context>
    <name>UpdateMessage</name>
    <message>
        <location filename="update_message.ui" line="14"/>
        <source>Update for ClipGrab</source>
        <translation>Ажурирање за ClipGrab</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="116"/>
        <source>ClipGrab %1 is now available (you are using %2). Would you like to install the update?</source>
        <translation>ClipGrab %1 е веќе достапен (вие го користите %2). Дали сакате да го инсталирате ажурирањето?</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="130"/>
        <source>There is an update for your version of ClipGrab!</source>
        <translation>Постои ажурирање за вашата верзија на ClipGrab!</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="64"/>
        <source>Skip this update</source>
        <translation>Прескокнете го ова ажурирање</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="91"/>
        <source>Download update</source>
        <translation>Преземете го ова ажурирање</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="240"/>
        <source>about:blank</source>
        <translation>за:празно</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="74"/>
        <source>Remind me later</source>
        <translation>Потсети ме подоцна</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="41"/>
        <source>The update will begin in just a moment …</source>
        <translation>Ажурирањето ќе започне за момент ...</translation>
    </message>
</context>
<context>
    <name>converter_copy</name>
    <message>
        <location filename="converter_copy.cpp" line="28"/>
        <source>Original</source>
        <translation>Оригинал</translation>
    </message>
</context>
<context>
    <name>converter_ffmpeg</name>
    <message>
        <location filename="converter_ffmpeg.cpp" line="216"/>
        <source>MPEG4</source>
        <translation>MPEG4</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="217"/>
        <source>WMV (Windows)</source>
        <translation>WMV (Windows)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="218"/>
        <source>OGG Theora</source>
        <translation>OGG Theora</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="219"/>
        <source>MP3 (audio only)</source>
        <translation>MP3 (само звук)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="220"/>
        <source>OGG Vorbis (audio only)</source>
        <translation>OGG Vorbis (само звук)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="221"/>
        <source>Original (audio only)</source>
        <translation>Оригинал (само звук)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="356"/>
        <source>No installed version of avconv or ffmpeg coud be found. Converting files and downloading 1080p videos from YouTube is not supported.</source>
        <translation>Неможе да биде пронајдена инсталирана верзија на avconv или ffmpeg. Конвертирање и преземање на 1080p видеа од YouTube не е поддржано.</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="371"/>
        <source>The installed version of %1 is outdated.
Downloading 1080p videos from YouTube is not supported.</source>
        <translation>Инсталираната верзија од %1 е застарена.
Преземање на 1080p видеа од YouTube не е поддржано.</translation>
    </message>
</context>
<context>
    <name>messageDialog</name>
    <message>
        <location filename="message_dialog.ui" line="14"/>
        <source>Dialog</source>
        <translatorcomment>Дијалог прозорец</translatorcomment>
        <translation>Прозорец</translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="48"/>
        <source>Close this message</source>
        <translation>Затворете ја оваа порака</translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="71"/>
        <source>about:blank</source>
        <translation>за:празно</translation>
    </message>
</context>
<context>
    <name>video</name>
    <message>
        <location filename="video.cpp" line="261"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
